% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %                                                                       %
% %    Matlab function for lecture                                        %
% %    "Correlation analysis of multivariate time series and              %
% %     Principle Component Analysis"                                     %
% %    by Christian Rummel                                                %
% %                                                                       %
% %    BENESCO lecture series                                             %
% %    "Signal Analysis and Brain Oscillations in Health and Disease"     %
% %    Bern, 2016/04/01                                                   %
% %    Bern, 2017/03/31                                                   %
% %                                                                       %
% %    - use real EEG data to build artifical EEG                         %
% %      with reduced channel number and block-wise correlation pattern   %
% %    - this function remains uncommented                                %
% %    - as a home work analyze it and find out why and how a             %
% %      correlation pattern is artificially induced                      %
% %                                                                       %
% %    usage:                                                             %
% %    EEG_blockcorr = blockcorr_EEG (EEG, corrpatt,SNR)                  %
% %                                                                       %
% %    input values:                                                      %
% %    EEG            input EEG data matrix                               %
% %                   (L rows: temp. samples, M_old columns: channels)    %
% %    corrpatt       matrix to induce correlation pattern                %
% %                   (M_old rows, M_new columns)                         %
% %    SNR            signal to noise ratio                               %
% %                                                                       %
% %    output values:                                                     %
% %    EEG_blockcorr  correlated artificial EEG                           %
% %                                                                       %
% %    written by C. Rummel, 2016/03/23                                   %
% %    modified 2017/03/28                                                %
% %                                                                       %
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function EEG_blockcorr = blockcorr_EEG (EEG, corrpatt,SNR)

    [T,M_old]     = size(EEG)
    [M_use,M_new] = size(corrpatt)
    
    [V,D]         = eig(cov(EEG));
    A             = zscore(EEG*V);
    
    corrpatt_SNR  = randn(M_use,M_new);
    corrpatt_SNR  = corrpatt_SNR * std(corrpatt(:))/std(corrpatt_SNR(:)) / sqrt(SNR);
    corrpatt_SNR  = corrpatt_SNR + corrpatt;
    
    EEG_blockcorr = A(:,1:M_use)*corrpatt_SNR;
    
end


